@@ -10,7 +10,7 @@ class stackedAreaChart(NVD3Chart):
 
     .. image:: ../_static/screenshot/stackedAreaChart.png
 
-    Python Example::
+    Python example::
 
         from nvd3 import stackedAreaChart
         chart = stackedAreaChart(name='stackedAreaChart', height=400, width=400)
@@ -21,7 +21,7 @@ class stackedAreaChart(NVD3Chart):
         chart.add_serie(y=ydata2, x=xdata)
         chart.buildhtml()
 
-    Javascript example::
+    Javascript generated::
 
         data_stackedAreaChart = [{
                   "values":[
